(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    144128,       2672]
NotebookOptionsPosition[    143143,       2648]
NotebookOutlinePosition[    143646,       2667]
CellTagsIndexPosition[    143603,       2664]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 StyleBox[
  RowBox[{"Stokes", "-", 
   RowBox[{
   "Line", " ", "Drawer", " ", "for", " ", "scalar", " ", "preheating"}]}], 
  "Title"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"When", " ", "V", 
   RowBox[{"(", "t", ")"}], " ", "is", " ", "given", " ", "by", " ", "an", 
   " ", "inverted", " ", "quadratic", " ", "potential"}], "Title"]}], "Input",
 CellChangeTimes->{{3.8249492389109564`*^9, 3.8249492750362473`*^9}, {
   3.825047765208081*^9, 3.8250478083172555`*^9}, {3.82505560244838*^9, 
   3.825055606739391*^9}, {3.8251130251298943`*^9, 3.8251130755204744`*^9}, 
   3.8251351636295986`*^9},ExpressionUUID->"bc70f9da-5b8a-493c-9dbf-\
7c6d8cd4633d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"FindTP", 
    RowBox[{"(", 
     RowBox[{"find", " ", "turning", " ", "points"}], ")"}], " ", "and", " ", 
    "FindSP", 
    RowBox[{"(", 
     RowBox[{"find", " ", "singular", " ", "points"}], ")"}], " ", "has", " ",
     "to", " ", "be", " ", "customized", " ", "for", " ", "your", " ", "Q"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FindTP", "[", "Q_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{"x", "/.", 
        RowBox[{"NSolve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], "&&", 
           RowBox[{
            RowBox[{"-", "3"}], "<", 
            RowBox[{"Re", "[", "x", "]"}], "<", "3"}], "&&", 
           RowBox[{
            RowBox[{"-", "3"}], "<", 
            RowBox[{"Im", "[", "x", "]"}], "<", "3"}]}], ",", "x"}], "]"}]}], 
       "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "function", " ", "finds", " ", "the", " ", "initial", " ", 
    "three", " ", "branches", " ", "of", " ", "the", " ", "stokes", " ", 
    "lines", " ", "at", " ", "each", " ", "Turning", " ", "points"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SolTPbranch", "[", "a_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"dx", ",", "x", ",", "y", ",", "bp"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dx", ":=", 
        RowBox[{"0.001", 
         RowBox[{"(", 
          RowBox[{"x", "+", " ", 
           RowBox[{"I", " ", "y"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"bp", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", " ", 
           RowBox[{"I", " ", "y"}]}], ")"}], "/.", 
         RowBox[{"NSolve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Im", "[", 
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Q", "'"}], "[", "a", "]"}], "dx"}], "]"}], "dx"}], 
              "]"}], "\[Equal]", "0"}], "&&", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "\[Element]", 
             RowBox[{"Circle", "[", "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Arg", "[", "bp", "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "StokesGetRep", " ", "and", " ", "Stokesfind1", " ", "finds", " ", "the", 
    " ", "most", " ", "probable", " ", "direction", " ", "from", " ", "the", 
    " ", "given", " ", "point", " ", "on", " ", "the", " ", "stokes", " ", 
    "lines"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"StokesGetRep", "[", 
    RowBox[{"xo_", ",", "\[Theta]o_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ang", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ang", "[", "1", "]"}], "=", "\[Theta]o"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", 
        RowBox[{"i", "<", "iMax"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ang", "[", "i", "]"}], "=", 
         RowBox[{"Stokesfind1", "[", 
          RowBox[{"xo", ",", 
           RowBox[{"ang", "[", 
            RowBox[{"i", "-", "1"}], "]"}], ",", " ", 
           RowBox[{"\[CapitalDelta]\[Theta]", " ", 
            RowBox[{"PMi", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "i"}], "+", "2"}], ")"}]}]}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ang", "[", 
       RowBox[{"iMax", "-", "1"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Stokesfind1", "[", 
     RowBox[{"xo_", ",", "\[Theta]o_", ",", "d\[Theta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "f", ",", "\[Theta]", ",", "z", ",", "mini", ",", "i", ",", "tab"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "\[Theta]_", "]"}], ":=", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"Q", "[", 
           RowBox[{"xo", "+", 
            RowBox[{"dr", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
               RowBox[{"I", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], "]"}], 
          "]"}], "dr", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
           RowBox[{"I", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", "\[Theta]_", "]"}], ":=", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"Q", "[", "z", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", "xo", ",", 
              RowBox[{"N", "[", 
               RowBox[{"xo", " ", "+", "  ", 
                RowBox[{"dr", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
                   RowBox[{"I", " ", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], 
               "]"}]}], "}"}], ",", 
            RowBox[{"WorkingPrecision", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
        "*)"}], "\[IndentingNewLine]", " ", 
       RowBox[{"mini", "=", 
        RowBox[{
         RowBox[{"Ordering", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", 
                RowBox[{"\[Theta]o", "-", "d\[Theta]", "+", " ", 
                 RowBox[{"d\[Theta]", " ", 
                  RowBox[{"i", "/", "PMi"}]}]}], "]"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", 
               RowBox[{"2", " ", "PMi"}]}], "}"}]}], "]"}], ",", "1"}], "]"}],
          "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Theta]o", "-", "d\[Theta]", "+", " ", 
        RowBox[{"d\[Theta]", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"mini", "-", "1"}], ")"}], "/", "PMi"}]}]}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "GetStokesTable", " ", "generates", " ", "tables", " ", "of", " ", "the", 
    " ", "points", " ", "on", " ", "the", " ", "stokes", " ", "lines", " ", 
    "using", " ", "StokesGetRep"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetStokesTable", "[", 
    RowBox[{"k_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "nn"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sX", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"TP", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"angS", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"TPbranch", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"stepN", "+", "1"}]}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"sX", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "=", 
          RowBox[{
           RowBox[{"sX", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "j", ",", 
              RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "+", 
           RowBox[{"N", "[", 
            RowBox[{"dr", " ", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{"I", " ", 
                RowBox[{"angS", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "j", ",", 
                   RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], ")"}]}]}], 
            "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"SPTP", "=", 
          RowBox[{"Join", "[", "TP", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"domain", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "-", "0.04"}], "<", 
              RowBox[{"Re", "[", 
               RowBox[{"sX", "[", 
                RowBox[{"[", 
                 RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], "<", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "+", "0.04"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Im", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "-", "0.04"}], "<", 
              RowBox[{"Im", "[", 
               RowBox[{"sX", "[", 
                RowBox[{"[", 
                 RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], "<", 
              RowBox[{
               RowBox[{"Im", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "+", "0.04"}]}]}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"nn", ",", 
              RowBox[{"nTP", "+", "nSP"}]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"i", ">", "10"}], "&&", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"DeleteDuplicates", "[", "domain", "]"}], "]"}], "==", 
             "2"}]}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"sX", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], ">", 
            "Swindow"}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"angS", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "=", " ", 
          RowBox[{"StokesGetRep", "[", 
           RowBox[{
            RowBox[{"sX", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], ",", 
            RowBox[{"angS", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "j", ",", 
               RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "]"}]}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"sX", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "j", ",", "n"}], "]"}], "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "stepN"}], "}"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Your", " ", "setups", " ", "here"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Q", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "1"}], "-", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"a", " ", "t"}], "]"}], "^", "2"}], "+", 
   RowBox[{"0.3", " ", "I"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"Pi", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"Q", "[", "t", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dr", "=", "0.01"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Step", " ", "of", " ", "the", " ", "move"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stepN", "=", "230"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Maximum", " ", "number", " ", "of", " ", "steps", " ", "for", " ", "each",
     " ", "stokes", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[CapitalDelta]\[Theta]", " ", "=", " ", "0.4"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "StokesGetRep", " ", "searches", " ", "direction", " ", "in", " ", "the",
       " ", "range"}], " ", "-", "\[CapitalDelta]\[Theta]"}], "\[Rule]", " ", 
    RowBox[{
     RowBox[{"+", 
      RowBox[{"\[CapitalDelta]\[Theta]", ".", " ", "Make"}]}], " ", "this", 
     " ", "parameter", " ", "small", " ", "if", " ", "stokes", " ", "lines", 
     " ", 
     RowBox[{"merge", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"PMi", "=", "10"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "search", " ", "step", " ", "of", " ", "the", " ", 
     "direction", " ", "is", " ", 
     RowBox[{"\[CapitalDelta]\[Theta]", "/", "PMi"}]}], ",", " ", 
    RowBox[{"repeated", " ", "iMax", " ", 
     RowBox[{"times", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"iMax", "=", "4"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{"Depth", " ", "of", " ", "the", " ", "direction", " ", "search"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Swindow", "=", "4."}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"StokesGetRep", " ", "stops", " ", "when", " ", 
     RowBox[{"Abs", "[", "sx", "]"}]}], ">", 
    RowBox[{
    "Swindow", " ", "or", " ", "reaches", " ", "at", " ", "another", " ", 
     "turning", " ", "points", " ", "or", " ", "singular", " ", "points"}]}], 
   "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"===", "===", 
     RowBox[{"\[Equal]", "\:672c\:4f53"}], "===", "===", "===", "==="}], "=", 
    RowBox[{"===", "===", "===", "===", "\[Equal]"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"TP", "=", 
   RowBox[{"FindTP", "[", "Q", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<Your turning points are at\>\"", " ", 
  RowBox[{"MatrixForm", "[", "TP", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nTP", "=", " ", 
   RowBox[{"Length", "[", "TP", "]"}]}], 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "Turning", " ", "Points"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nSP", "=", " ", "0"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "Singular", " ", "Points"}], " ", "*)"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TPbranch", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"SolTPbranch", "[", 
      RowBox[{"TP", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "nTP"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", "[", "TPbranch", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Initializing", " ", "the", " ", "Matrices"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bt", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{
      RowBox[{"N", "[", "0", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sX", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3", ",", "stepN"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "stepN"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"angS", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3", ",", "stepN"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "stepN"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"StokesList", "=", 
    RowBox[{"ParallelTable", "[", 
     RowBox[{
      RowBox[{"Catenate", "[", 
       RowBox[{"GetStokesTable", "[", 
        RowBox[{"k", ",", "j"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ComplexListPlot", "[", 
    RowBox[{
     RowBox[{"Catenate", "[", "StokesList", "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], "-", 
         RowBox[{"2", "I"}]}], ",", 
        RowBox[{"3", "+", 
         RowBox[{"2", "I"}]}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"ComplexListPlot", "[", 
    RowBox[{"TP", ",", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\[FilledCircle]", ",", "50"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], "-", 
         RowBox[{"2", "I"}]}], ",", 
        RowBox[{"3", "+", 
         RowBox[{"2", "I"}]}]}], "}"}]}]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8230381122087593`*^9, 3.823038121157728*^9}, {
   3.8230384041556463`*^9, 3.8230384231245923`*^9}, {3.8230385171385546`*^9, 
   3.8230385458016977`*^9}, {3.82303858585093*^9, 3.823038595328173*^9}, {
   3.823038628758222*^9, 3.8230386742339635`*^9}, {3.823039321065159*^9, 
   3.823039327611306*^9}, {3.8230393789031305`*^9, 3.823039397235064*^9}, 
   3.8230394485073433`*^9, {3.8230397398403435`*^9, 3.823039741102245*^9}, {
   3.823039819626861*^9, 3.823039879574297*^9}, {3.8230399187100954`*^9, 
   3.823039945712809*^9}, {3.823040135933854*^9, 3.823040173961895*^9}, {
   3.8230402475720735`*^9, 3.823040247913655*^9}, {3.823040293852997*^9, 
   3.8230402944601955`*^9}, {3.823040520236519*^9, 3.8230405229659767`*^9}, {
   3.8230459500720778`*^9, 3.823045951788929*^9}, 3.823046199721779*^9, {
   3.823046404479682*^9, 3.8230464087514744`*^9}, {3.823046444328246*^9, 
   3.8230464468789396`*^9}, {3.8230465398707895`*^9, 
   3.8230465482199416`*^9}, {3.8230466725470653`*^9, 3.823046680312364*^9}, 
   3.8230467783291636`*^9, {3.823046832993461*^9, 3.823046851789612*^9}, {
   3.823046898352391*^9, 3.823046898653783*^9}, {3.8230469448880424`*^9, 
   3.823046945320058*^9}, {3.823047122436264*^9, 3.823047129043346*^9}, {
   3.8230472836014724`*^9, 3.823047284886017*^9}, {3.823047472713174*^9, 
   3.823047497235473*^9}, {3.8230476296740885`*^9, 3.8230476334474225`*^9}, {
   3.8231192209477277`*^9, 3.8231192635404897`*^9}, {3.8231193140373206`*^9, 
   3.8231193491660028`*^9}, {3.823119654168016*^9, 3.823119654684041*^9}, 
   3.823120136137907*^9, {3.8231201805058994`*^9, 3.8231201894783754`*^9}, {
   3.8231203029018183`*^9, 3.8231203189085236`*^9}, {3.823120600136722*^9, 
   3.823120600598389*^9}, {3.823120962225477*^9, 3.8231209627512693`*^9}, {
   3.8231214638985395`*^9, 3.8231214677799473`*^9}, 3.8232151075611963`*^9, {
   3.823215155528163*^9, 3.823215157621708*^9}, {3.823215238855918*^9, 
   3.8232152391827455`*^9}, {3.823215377406497*^9, 3.8232153955586233`*^9}, {
   3.82365417587976*^9, 3.823654208645379*^9}, {3.8236544326919403`*^9, 
   3.823654433098284*^9}, {3.823654782389432*^9, 3.823654803899276*^9}, {
   3.823655767160862*^9, 3.823655792332571*^9}, {3.8236564200224752`*^9, 
   3.823656420692004*^9}, {3.8236571861142287`*^9, 3.8236571896297655`*^9}, {
   3.823911444090046*^9, 3.82391146070953*^9}, {3.8239114911088576`*^9, 
   3.8239115323653593`*^9}, {3.8239122566022263`*^9, 3.823912285990092*^9}, {
   3.8239128133711576`*^9, 3.8239128589185023`*^9}, {3.8244404636918907`*^9, 
   3.8244404715509644`*^9}, {3.8244409223790913`*^9, 3.8244409869730706`*^9}, 
   3.8244416681456084`*^9, {3.8244425651996264`*^9, 3.824442666927389*^9}, {
   3.824443277817015*^9, 3.824443298957965*^9}, 3.8244439576297007`*^9, {
   3.82444399370301*^9, 3.8244440094887915`*^9}, {3.8244441515827875`*^9, 
   3.8244441905203304`*^9}, {3.8244447142705107`*^9, 3.824444739553271*^9}, {
   3.8249516839273605`*^9, 3.824951948692665*^9}, {3.8249519903646326`*^9, 
   3.8249526771768026`*^9}, {3.8249527168795843`*^9, 3.824952755863985*^9}, 
   3.8249527909423943`*^9, 3.82495282189541*^9, {3.824952953677147*^9, 
   3.824952954283682*^9}, 3.8250384613645315`*^9, {3.825038857164904*^9, 
   3.825038884160663*^9}, {3.8250389187083693`*^9, 3.825038924629775*^9}, {
   3.825038955895584*^9, 3.825039047926175*^9}, {3.825039516177226*^9, 
   3.825039531911244*^9}, {3.825039575145588*^9, 3.825039593270872*^9}, 
   3.8250401719890795`*^9, {3.8250402263644457`*^9, 3.825040235536263*^9}, {
   3.8250404054520016`*^9, 3.82504041601469*^9}, 3.8250404792440443`*^9, {
   3.825040627439445*^9, 3.825040635193365*^9}, 3.825040765405196*^9, {
   3.825041526833226*^9, 3.8250415500049105`*^9}, {3.8250417475828156`*^9, 
   3.8250418357080345`*^9}, {3.8250420103641825`*^9, 
   3.8250420141147404`*^9}, {3.825042101788607*^9, 3.8250421082547398`*^9}, {
   3.8250422575082345`*^9, 3.82504227567653*^9}, {3.8250425843349686`*^9, 
   3.82504263433325*^9}, {3.825042810989385*^9, 3.825042880551962*^9}, {
   3.825043234114007*^9, 3.8250432386610556`*^9}, {3.825043280536135*^9, 
   3.8250432864262056`*^9}, {3.825043737131957*^9, 3.8250438012444105`*^9}, {
   3.825043851161379*^9, 3.8250438881610003`*^9}, {3.8250440370674615`*^9, 
   3.8250440720674562`*^9}, {3.8250444298954983`*^9, 3.825044451941949*^9}, {
   3.8250451040988255`*^9, 3.825045124210023*^9}, {3.8250453834577937`*^9, 
   3.8250454105359616`*^9}, {3.825045618426635*^9, 3.825045652442179*^9}, {
   3.825046067973283*^9, 3.825046096754877*^9}, {3.8250471519422*^9, 
   3.825047173536248*^9}, {3.825047494848358*^9, 3.8250475216146336`*^9}, {
   3.8250528298503647`*^9, 3.825052881701392*^9}, {3.8250532259724817`*^9, 
   3.825053241021679*^9}, {3.825053729666233*^9, 3.825053736857321*^9}, {
   3.825054130770846*^9, 3.825054141616915*^9}, {3.825054360223475*^9, 
   3.825054368223543*^9}, {3.8250546153484526`*^9, 3.825054630973682*^9}, {
   3.825054663051591*^9, 3.8250546863956776`*^9}, {3.8250551271145334`*^9, 
   3.825055137520564*^9}, {3.8250557124580793`*^9, 3.825055732723209*^9}, {
   3.825056097178259*^9, 3.8250561053021584`*^9}, {3.8250565283022213`*^9, 
   3.8250565715832944`*^9}, {3.8250572379272175`*^9, 3.825057246770585*^9}, {
   3.8250572942861257`*^9, 3.8250573176772566`*^9}, {3.8250574320831165`*^9, 
   3.825057474395358*^9}, {3.825104572083064*^9, 3.8251045836610184`*^9}, {
   3.8251046288644023`*^9, 3.8251046461299467`*^9}, {3.8251352268642664`*^9, 
   3.825135227290603*^9}, {3.825135311567214*^9, 3.825135333523367*^9}, {
   3.8251354048019924`*^9, 3.8251354735358324`*^9}, {3.825135831301956*^9, 
   3.8251358323023834`*^9}, {3.8253725805516615`*^9, 
   3.8253725981142817`*^9}, {3.825372665504289*^9, 3.8253726830983067`*^9}, {
   3.825372786881263*^9, 3.8253727915520144`*^9}, {3.8253729695354905`*^9, 
   3.825372971817153*^9}, {3.825373679176504*^9, 3.8253737107543173`*^9}, {
   3.8389671478651323`*^9, 3.838967174975068*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"b64d2191-17bf-44d5-9569-bb0d8fa1db1c"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJw1m3k8VN//xweZsX8KCYWklKUSLULOLYqotIlElKVUokLSIiJLJUkiJUvZ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       "]]},
     Annotation[#, "Charting`Private`Tag$20247#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{389., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3, 3}, {-2, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.8253726028792286`*^9, {3.8253726722077403`*^9, 
   3.8253726835981627`*^9}, 3.8253727943014774`*^9, 3.825372972410427*^9, 
   3.825373711551451*^9, {3.83896715464624*^9, 3.8389671755680895`*^9}},
 CellLabel->
  "Out[111]=",ExpressionUUID->"3369bca6-f278-400c-a62b-a96e92aab0d4"],

Cell[BoxData[
 RowBox[{"\<\"Your turning points are at\"\>", " ", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"-", "2.933634982333688`"}], "+", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{
         RowBox[{"-", "1.0663650176663122`"}], "-", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{
         RowBox[{"-", "0.9336349823336878`"}], "+", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{"0.9336349823336878`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{"1.0663650176663122`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{"2.933634982333688`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.568481643970859`", " ", "\[ImaginaryI]"}]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.8253726028792286`*^9, {3.8253726722077403`*^9, 
   3.8253726835981627`*^9}, 3.8253727943014774`*^9, 3.825372972410427*^9, 
   3.825373711551451*^9, {3.83896715464624*^9, 3.8389671756774073`*^9}},
 CellLabel->
  "Out[114]=",ExpressionUUID->"1e552e77-bff1-4ed2-b8f7-d802958df240"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4586217`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.8253726028792286`*^9, {3.8253726722077403`*^9, 
   3.8253726835981627`*^9}, 3.8253727943014774`*^9, 3.825372972410427*^9, 
   3.825373711551451*^9, {3.83896715464624*^9, 3.838967177210333*^9}},
 CellLabel->
  "Out[122]=",ExpressionUUID->"24453182-35cf-4463-84b3-7aae66d2b708"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}}, {}, {{}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJztjok31A0Xx6WY5ff7HdqVpAUVSSGS5RZZ2t5HWlCWFG/aXr1PtFFC8Yw9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        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVXk0lYsXdb977/dFpBLRoJQKt5RoonwvKUWhDKXkPckQ7yUZUkh64ZUM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        "]]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVUnk4lXsX/b3ve84hSQO5kjGVuhWKDE37dalUkkuiNBhCg4SiaBD33lSS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        "]]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVXk4ldv/PY4ht2hAA5klqhsZ46Z8laKRlAi3yVSRoohKotsgUygZGgyZ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        "]]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlXk0lg0Txm29okSheEuivFlKJVLClBaVLJUllRYSRYlQItKCilLJVlJK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        "]]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlHc41Y0Dxe/I+6rISomQmQYaRFPyKml5qYx2qF6EsrIqbolUpJAyQpFr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        "]]}, 
      {RGBColor[0.363898, 0.618501, 0.782349], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVUXk01Yv3va6hQWRIPCUlRKiINHxzPnghSqVUJCVTJU+eSoZSZEqFylRP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        "]]}, 
      {RGBColor[1, 0.75, 0], PointSize[0.003666666666666667], 
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlnk01Y0TxiUlok1KSUUppRSSSL4tQin7ksJbJNJbKZGyJUUpJUuKsiRZ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        "]]}, 
      {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.003666666666666667],
        AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVjnc81Ysfxo/jWIm6aMlOcbsVsuo2Pl9RGjdKoehWVmZFLlEZyb0aGiS6
pET2LI6tj1H27JjZnOFw7HXs3/398bye1/uP5/165C1vG9mQSSQS87/8v19V
O3uY9I3iB5t4B5LaABg3dF0JfTeKb2MdU0SuDQB36TPX+vIovmqjagw/H4Cb
v+/Jsto8ilxGxB3hogGo5nvREkzjoKvfFw0XzgA0iReE7Aji4LkdVfbXpAZh
7L7NM4YBB/N2yT0P+mMQzpF519rXc9Byyz4nAa9BqNfeeli1ZgRJUZO/UtL+
Y/NT3/OejKC37a51er2DoDf2e6/byRF8IK/cUb6RDm99yllhAiNoYPyVXX+M
Dvux+Oxo+TDSjF/9sc2NDqr23Ivu/wwj12KgNjaeDpYnj9rbnhhG+d84Q9Sf
dPirjTUUyD+MNrExfgKiDNgcyd7MKmdj5oaD1uE6DFBWfmefHMBGoYdC6ulu
DPCf1d4fe5KN92rT4ihJDJCZ/vGlWYiNxTknH4f3MIDvn1o755ohlFOTjsoQ
Z4KgQFbEsedDqKn82Yf/FBOS3QsDzxgO4W6/LeMR3kwIYOQVlv4yhI7T51rS
s5ggVbPlpkszC1O8+KPJI0yIm5HvMQ1jYV2DjlSIPAuqprxepZmx8M3mD8ej
L7HAuFao7IgMC1/UbnIee8mC03ydmUcHmKij9WyMWsGCl16nBzzimMgItsb8
NRYYGfA95zgwcZ8HPX5ZewgiipxGaCpMvKzqKZrrPAQP5Ap9Z2cYyKxb/pme
OAQlI6lPz+cz0Ew6s2lwYAjC7spo7fBlYPT293YvpdhgzjshonqCgZviRdzc
TdjgG/RqJnM9AxWWFbJpr9hQfVqhyJVGR/GIbqpjDRsUjVJjbofTMZdRq3WU
fxieL5zwpFvQkfKsh/S3zjCIK96VDf2VjpITVsF8XsNgZXqyyX9yEBfeclMw
dxgK6PdOj+UNIun4c2nOzDD8xjfq/cZvEKNqw83Oq41AlUtuW+6ZQeyetbij
dGsEnBy3/yu5aRCFX06HaSaPgP418+X8ngFUOXD62f2hEQiKkjHoSBhA9ia1
y6q7OBCqTOFouQ7ggc5b6lLWHNgZHVMtfnQAlW+ZWrlFc/77YxypKjSAgzry
XZR+DryTeRHxvLkfE0f2X6mWHYXePbtCHaP68Vvizp1LV0ehW2WDxVOnflRR
0lGxeD8K78Yf3/7tYD+2XBKYUe0ZBW5v3oQIfz8ufuxT05QZgz2yhyT30/rw
ek5K7M2rY1BUIKHxM6oPb9QpFIh8GIMGEac33271ofvNwUP9vWNgb8a/Q+NI
H9Z92FwhKT8Opfo/Q5jCfSjSyT/5j+U4RM5oHMml9qKWk6Tbzk/j8EDYip5x
sRePxTf3KDHHoTXyzJjqTA9qFDSz90pMQHhkEqc4pAdVNssKeGpOgKhNwv0O
zR6MDnn8sMtkAoz7eowp7d2oPSl61tljAuITX7Jz73VjwNXr66XCJ0DI4MXb
eelu7LDf9663YAI4cdc+nintwsSIOMsf3RPwhP81a7dtF6o2S77sWpuAqcqP
5fIiXXjnopnUJoVJKM6jkGIzO1H7rwOfrPUm4bZd0GSWWSe+5C0g19yYhLvx
MQ695E58dORA9NUnk7Dbg/05LPknVh3tShZMmYQoNkuh5+JP1Jw4u1RZPwmO
isHzOmsdGHR3yo46OQnH9Sl8mkkdyOqvS8uRmILWK0sv9E06UPB+rxZDewre
C/mZD5M7sI23TFnZfAr4dpJLpTPa0WeDzzVf7ymwrbxw3fVqOzJq4jLI0VPg
rHE2wkykHbVfabb9+30KzKPmK2iFbdgR05F6nD0F0toFzS4321DxxZW/JEWm
obYnsz5apg27xLzv8apNQ6aBTfhiYyt+4ml6IWE8DWJGNqeYj1qxAgNdDnpO
g0bOP3tuaLfi6mz1skvkNFxkkELujbSgSMardV9LpmEx3GoqN6oFXYcUklWZ
0yD0Qbo00KQFBxKazLPXzUCZ5+y5ufUtaLb1/JyBygxUagzpBX5rRjkVmFx/
cQb6l9915z5oxun1nyy7PWbA39L6xgPNZnzpzthRHDkDp4yq0m6N01Aj6tvG
itIZuJh//zs3kYaZG6Gjl/WfX/f8tKQNDRW/3DJZJzILZ6V9fVvkaFjUbWZx
Yv8sZKB/dEn3D9z5JVAs1nQW1t36zj0R8QM3ntvRJeE1Cz+95yttLv/AoBvd
oW+iZ2Gfmcolma0/cKTPdrtS5Szc6d29X7i9CYtiLhR1jM5C/lpUaPDbJqQE
p355Jz4HbyNkK7MuNyFNsZt2++AcROoEC97Z3oSGfQcWjK7NQTb/zt03ehqR
5Zaabvz3HNQyIqXmPjbimZjRKdvkOaB7XJFVuNGIPnkiEU+a5kCCKuUyvLsR
DzF+8c2fn4M750c/vO9rwNZLY56L0vOQ91fh1EenBtRzD7h+Sm8e/KnGnduW
6lHgvWAC1WEenuStK619Wo8bL4VaqQbNw7h4pFTB9npctW9zyMuZB6OgR9cY
qXXIjbB6c65nHqKL2CtndOpw3WBZ/iyFC9cd0+3HW2ox7NmdLwm/cUHrsJ14
o2Mt0qw6L9gbcYGz29xhjFyLRkxzd21PLuRs9us6HVGDMda6k2JRXBgxfNLK
0KjBRTVaxFI5Fyi7GsqwoRpH6o6enRzlgsRdK9EOx2pU3ZDSNS2xAE8IAdn9
QtX40EBdnvfwAlxS2/NnTXwVugf1TspYLYDfkZl9sfpV6EVN26n/dAFI6moL
OFSJLeFBr+9/XgCBc9ayUs8qMcrQSaywfQGoP4t48/dV4vLvmz0FSYsgmS8l
EE6rwL0nzd5fV1qE2I2iTwo9K7Dxl/lL3wwWYbqtliUvX4FyIh981N0XYc1L
x7e6qhz1qNyh1MhFyH3Ek5btWo5J2e8d1b8vAlfKsIYpU47OknI9ZZxF6Gna
qmZe8x3bXUhbrkkswUv5BS0Jz+9YzZPLoRxeArNdWupiyt/xylimJtVqCY4d
Krln3P4Nb98wqbz9bAmGo7Usep58Q4OGuXsamUsQvC5F3/bQN9x7IGzvws8l
eB1mJKs1VoZHLvu1VpCXQdNk+8Ez0WWYF7B4Jmr3MgRpf6THmZbhXz+0rf2M
lmHTV2XnU6JlmLTXbvbmvWW4m/xBWb28FNvep7dYRi9Dx9vN/VLepUjZOE81
rV4Gu0hxMQPtUqzvuF1gPLUMNYKtfBWTJTgev7vwiuQKKD84zvc4tQRVC/a9
cDq2An+PZ1FO2ZegS/3+6w8cVkDkFwtTo10lmKLs3RESvAJTxEPdT/Ri7Mjl
a6Tmr0CV4YwIfCrGHQHUbb0DKxB11ba9w6oYbxrbWAkKr4LS8cxvRYrFeD5d
rvWg+ipM5Qvtbq1DrLxQqu9qvgqhIynVqkaIwLXKS3m0ClxHMlWm4yuO6n5d
G01ehaPtK7ZRll/x6p8RE1rNq+CvtyCpwCnCBnePfp/lVci0+il2wKMIc+6F
GzUqroFD7J6qAf4iJBIKtimfXQN5lrfP8zeFWNXS1efjtgYK9K2OdbsKcSA/
ndYTuQY5/dtJMfkFGHW9t0KvfA3+6JV542FQgFf5NxQmja2Bn/GcHp2ej2kv
PpQ9EyYRuTV1M4b383FvuPavpbIkwmVs3z4jiXwMkpNhLKmTCIODW/8cSc/D
C3TpgQMnScRv/jyB/mfycFOCdK/bFRJheCp/G5Wdi1LkVYFsZxLhKuoazwjI
xR1XelTn/EmEjOCzxVTlXOQ3snI++C+JqOKJOetelYNs/aH0B6kkop45WdXq
lIPq0T8mSktIRC9PWGODWA4mkvuk17eSiAmpw22VudkoazV62niYRFQzI8vN
LLJRxLzd4OMqifiUsUblCGXjklGZ0agYDyF2s4a9hUpFX0/drYeVeAjfX8Ok
da9TkS+qrPvpIR7iQEDxmIAoFW0Snht2GfIQE3Q21hZk4fcM05K91jxEwjHx
oCD7LNyZJ6/u48FDCK7SjCe2ZaHME9YhWiAPYZcXImlYnYlbLqfqKX3kIYSO
Oe066ZWJmrIyDV5UHiKpWne/jmomXmC8uNxcxUM0j8y1NDO+4FkV03N7e3iI
1fVJnnYRX1DfU1b/nykeYu7tMd6wC1/Q7DQ7pJ+fTIwpdgZ+F/6CN7dnDhze
TiaYGa6bZ8o+oy/ngepbFTIhpUI0FXl/xkbaOM7qkgmj1PWBAQc/o1yBpeGF
S2TCTjiqmDOXgVuGdwhnOpEJb3v12fNZGSi6jVEu9pBMhFSU/5rjkoF8J+P8
7rwhE7oiXOlctQzMT7hk3JxIJuixRop3BtPxtpCwstZXMhH7eZdYil06Chsb
Lv/7g0zcKFpcY4ymYXzU68YVJplQqqoflXVNQ11O2yeLJTJxf3uTRfBKKjqV
/GFTsYGXaLhJa6E8TsU3oSU79yryEjuKW07dFUvFr45azOADvMSR1FOoEJ2C
JBsPr8U/eAnT8CKNerUUPHY1X8LSgpdwCVBL8ixJRn/T5eQqN17iuHNf6FWT
ZET5OIr6U15i2+WXj3RHknBxxPDPd+95iVGdo87Kvkmomb1A5cvkJT5vvaun
L5mEokqf8p0reAm38fStN7ISkRVmgJ2dvMTB8iGOv0EiFgsulJ2Y4CVW3smX
xAwl4L+eMZWfKRTC+nYuazkgAYdjGVYy2yhEjY6hqIlSAh76obT2dC+F2C/B
1Egvj8fAVfvweR0KYRuhLq7rGI+t5zqybUwoxDuFh5OtG+JRLuYkjeZAIZoS
6xscsuLQYTZnXMeHQvCrSaWtXorDLH2l9Rmv/9vbrsTUkeMwLNQ0RDaBQvwP
LNKjog==
        "]]}, 
      {RGBColor[0.571589, 0.586483, 0.], PointSize[0.003666666666666667], 
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVjnc81Yv/x4/jIBmVXMmMMupWyKpv432looWUES0riURdRWWkbhpSuaJI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        "]]}, 
      {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.003666666666666667], 
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVnk41Iv7daVEpHKJtGmVrSjJktNiK2Wnq+jelEjfW1KkkChLi1JIpNBi
K1zZRZ/Inm3GPpaZsYwxMx/GLpKf3x/neZ/zz3nO87zPe84r73jV0klQQECA
tYj/n2E1bl62DBJxTkmuAmq9xHpdz0JrGokdOh/tTtKZRHKa9y/LZhJpqzKM
Y0KZxHx9+sv5OhK5aioPSB0mYcln7kuuJEFYfqw+xGEQSaulKJYlJKqu7xKN
eMkgfqkb/ztfSIISkXR80JBBWFh7iyRnk8i6bCLtwaETiR7pHyzTSZSlGUXJ
GdGJuRfMw/NJJFpGjsqUvushVjxh6VknkHj52HfQQ6CHkAvk6nyMIXFmV17u
LoduQsmHf0AwgsTGCn5gd0EXoXN9UsMulATTUdHmmXQXYeI6q/5fEIn3C+e3
GVzvJFaK1UVl+ZGQrpQilzXSCEpa3K9cLxIhTypzqpRpRISZ+7nCayRmbW7d
efiggzg1ql9R7ErifxuUjE6w2ol14WuVSs6T6Onvklh5tJ3QsV+x4GZPomhB
3bcnro2w375A3WxDImbdA076r1bCd3gssfEkCS8N+ik/u1biTR7r9l1DErbm
GuVmuS0EcZdmugck9l1+pL5ZsoXgh8ZEP9YkcTfp7cjC1WZC/tXpfvZuErV9
BZ/otU2EZfK63QYKJGQ2Uy4Ru5qIezm0WwmbSVywZ++IC6ISV75cOpoqs+j/
Vl3Pkz4KYVcyI5a1ikRY1OcXdw5RCP3K4NYvyxf3mxNleuV1I7G7Tjq+TGDR
34efYkUTDYTUqgb+rRkeWHGnqorS64k5y+DDu/k8WMfk3Ct2qSOYkXjeP8hD
aYQkvm6pJVoYVHdDOg9B52ivmF01RLXSRavkVh6OqybMCEVVE8WeP/eK1vOw
cs7ZRsGiighacy1NppwHNQfjlKsrKgmzdPaOnUWL+oTCfG55OSFz/J94jSwe
bsqLWPz2KyPyxtcX8VN4SNv+ZNRV+zth+7qj7WM8D327JJ+3TZQQk4Yvxi9G
8SCr+lJdP+MbQd1u/qU+lAc8MOGkN30lMoRE7+2/z8OJ3ItXW4yLiIvxjQIm
t3kI7xPpM/laQGzQjbrztxsPtFVptqV784jmNodf1y/yIK9nXnMgJZtIFn+p
rWHPw1fPN61/bPpM+Bylek1Z8JB7tqM8clcG4aajF3DBiAfz8gvnqVKpxIW9
qY+oujxwlPgCEoIfiGlrh8ukGg831BN4U91xRKBOmXLODh70vZyVtAsiCckt
SsM+cjzs9DnTPKsQTHSEibweleAheTx03k7yFBG3MGhyUYiHgwvT1tsu+MO5
5a+J4BkucpPC7WlNz9G8UPfWlscFZzrJVmYiFocVj1psZ3Ahse2sgtLDd6h4
GbgmoYmLQj3LQr/oZGjvzhmvruAiWZH/XCg5DWvzjQXjC7jw+uGiTjudCYdW
8RNbP3GhUZ03qs/MgvS0At3qDRci4hFMOOeiYa2++/0wLrrN3SjaZD50z+9x
cAzgYt3aOye+u39BYhqRTl7nYkd8R1rrdDFanNd57nDiQn7usYKW3jcs8aSf
KrThQmfJNcMVd0sQaM7vmTPgollTIex1SSliNRvkuBpc+Dzwzx4WLINgjvWm
kO1caB0Ic5w/Wo6jDzNmqX9yQdmXdqzqfgU+tUcX3lrCxT4jic/C5ZUIsOcE
149y0H9R+/yCUDUyGaNJfnQOct8X5Z3Xr8Hlxklxei0HPl7Ozj73fkByiKH9
qoADoQ0c5s+SWmTG3/XL/sCB7t4rI60LdZg02nDV5xkHhIg19dzBBlzxejeR
4MPB6/V5ulsONkLW6KHzdmcOnnxr7NDtbMTJML68sAUH04I2u357UUD4vrpr
pM2BaNDLyPPSVDj/MdnL2sLBRqtrD12zqHiW6HcvUpQDxsqSnz1mTQg6WSX/
fnQIOtrrgoa5TVgn/u8OyfYhfK7mxb8IbobWfp8n4cVDCDhLr36zpQWKfvR/
Pd4OwbT+wjat4hb4rbGydQ0aQoaKoKjiqVaoh5i2lVwagpXxw4ZEfitiWo9u
Uj0xBHMTn3S3B20Ib7Uw+E9lCFnt00IB8u2osVo38WLlEFKENh6QKmjHvm+n
nCKH2XDdPvCEZdaBkuNSlZ/q2EhRXHabP9CBIx97zXo+srF+KvyaijcNg283
mN58wEb25fa8HolOeCynPFK+yEZm9+O+gnedoN4XtV04zMbkRgf/gv1deNFU
NqCzgY3cp+eLt1Z3YejbW7ycHoTPBgmXlNPd+DQlPfA3ZRBTS07nhnO7sebj
4ZRjqYMIY2kHh3n3wFjN0jQ+YBC2HWKreaJ06P51wVfu9CAmZPOOWUTTIftv
kdpStUHU9Yf/FyzJWMyVjLVnhQcx43JFcM1pBmID+N07ulnIuxzqbhjPQPH6
Zxr/fGbhrYc3bSuLAYs/5yiiwSzkyOyRSlFi4lxhrfWVMywYHWn/8cc1Jo75
s1X0d7MQZH4tXiCXCZqB980mwUW9X05rqbNMFDauVm1tGUDynxWzRuiFyaMq
5vPkAXwTeJH89F4vlr2SKhXxHkDKHwc7kit7IeuQ/1v75ADM1loZhK/og9W+
gsodmwZQbJLwwdSsDz9sL52s4/ejfl4+i/a8D+qvHL+plvbjrdIfOzVb+xBN
P7M3LLwfnnaMmHDZfhg8vFv26UI/8jneqt/s+zEiO/f+vkY/0mfPvyqK60d0
ikeg/bJ+vBc9sbygtx9HtfhO+9r6Fvtrn0fO9gHc3ru3sjKpD4JHlDz8XQaQ
qeKpcMarD66Xtnic/DgA9s6CB8PGfaCGyXrIDg9g05ZfHH/ZPmjnr/IY2MOC
7XqckOL04i1d2CPzOguh0gFpyYW9EBVeuOGby0LZqvKVuo964a46dePYTxbm
RJe7NZzpBc2GvCGlOwj1pSYUR+VeHPHtv8G8M4iuiPJM7XkmDoTWMrtLBhG0
7dDzNfVMqL7ONqUJsbEnu9Cd84aJbWmxX1qN2Og6S18i7MbERb0DZksesREi
IhS59TATyQ1Nvbvr2Rg5OS8cuIYJn/nPto9XD8H2+dRtVh8D5krPa9jWQ6jP
ThQIzWHgXPea9hsvh2DYZhu0N5gB96fhAwJdQ7ibfspskx0DjO9Mg6JNHIS7
zT4yV2IgqGM6M/E8ByZO2s+WzNGhPCK+8VkSB6X3my1G4+iQ4mebpnIXc+rn
4QJXAzpUuu7/Gt3NxbKrGZv7OT0wqLJO1brBReX9rtChsB7sZ2SHZuRzsTNr
y9/emj3w5XeetZrnwljXeCy6pxvpsY0t247wIFPj994gqBtk6qXUrcE8RIm5
UO+odiPGzDTCrJYHaTNzgfzWLhhNqN/xXk1C89X4Uj+/LnRs6NzXbEvi7MNK
vWaFLvC+Pb1qF0vCO+bT0nxqJ+5uuzwg2rv459ST2Yq+nbisaneSvXMYveaH
EpUVOjG9eFaj/w5DRfK7+tcmGnI/76/fnj0M0v33Z7ofDQHlMtaBs8NI6ey7
80yZhrRj4x8kDo+A61pHNnV0wPFb/a2y4BF8iPC1TQrugIZMcOC7+hFoV22U
ENvfAbd5J7SK8mESQjhHDLTDObNM674qHzECByUyItvRzyALDS35EBY/a2dv
2I4XDo6vN3jy8U+lWXTsdBvcYkK/LI/hQ2nPB3m3lDasbSofEf7Kh2S7rX7b
mTac3nviT7lePkYelFpSV7ah9veJJUeWjcJjMvX1udJWuObTX/gojiLktKZH
oGcrHI4Lp9SYjkJFY1xBT6kVDSqfJZWvj2IXAX95Zgsube0pyooaRaZ9dnxM
VAuiCbqJadEo3um5NqeYtuCJkU3MHGMUDprdLmbLWkA/Ve3/ZekYQly5KY++
NqNXLKszVHEMj+ebe8/ebMafSp7+7mZjCD9YxPlHrRnqzTXHvW+MwcowpGp2
sSdkCjO5kdFjiNX4Xaac1IQ7bUcOln4dw1TiUYVpxyZ4xdyTEegfw4xzj9bp
TU2wEXe2NRMZxzGV7EO2XVSELdQ1ZKgucmPRe9xoKtpVgx3krccxtDRdLPsv
KuKjRN5k3xrHlq6ueGkZKoST6D5/xY1jKvvUPcl2CjSvPqOKlY/DNO3gdOpL
Csq/Rt6kcMbxon4Fuu0okD9uqZ+4agJC1bGxqXIUbGqRW/1o/wQepytYSPY0
4qn9/lw/+wnQKBU3shIakRLsExEeMAGxfI2MEadGPI71acpNnkCn9WZUKTbC
ZIOWyVD9BAQc5MpvMxowGfm+SXFyAiZaJWlv/teAiIoEfW+5SUivysj89bMe
B+uWeNIOTyLRRuZYZEg99pg/gbHLJObesjguMvVYnjzpVfZkEpu1CsS8Uuqw
IEL/aZozCZa94cMF3TqMOd0Nm+ychPnnMcZ3Si0a9LQnUwSnUGe727/cuRZL
+j0XLu+awpfszTShhR+otHkepGM+ha6Vb+wCon6g+CrtnMzNKSiLq/1PT+0H
Xkk+dRF8MwUJEylfrdoasKx6r/0smwKTpTl13aUGxW9mrOe5U+hfo3loeGkN
0tlstrjkNB4nnStNfl+NuLYiISXtaSjl5fa+06/GV9LNz/rcNAS2DixlDFQh
MHti98OQaSSomTx1CKlCzaAi+SNjGrU7phjrlavQHj8UKts2jciuhDMbKZV4
7T/Ldv89jWmH/LOONyvRTV/X0rZ9BpUBFsZDGytxkz+nYHxyBuKh6h5ZlRXI
Hzvy5fuNGRRU1h0quVaB7DMPHI/HzsBJ8JJYg1wF/itrEKF8n8H/AQpyk54=

        "]]}, 
      {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVnk01Yv3vS6pzEPKUyIhkopIwy8nFKJUXiqSUqbIkyQZShmTQoqopwwZ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        "]]}, 
      {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       PointSize[0.003666666666666667], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwVVXc41Q0DvSO9KrJSImS2tUj7/KSElpdktF80EMrKqrgSqUhGyghJ9sjO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        "]]}, 
      {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVknc41o0Xxq3y0qBQektKeTNKJSWSUyiVrDJSaZAoSoUio6TSIIqsBiWJ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        "]]}, 
      {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVHk81OsbHWPIJeVaKpI1Ud3Imi51vkpRXZGS9bZZWixFERXSvS2yJaXQ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        "]]}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVUnk8lvkX/T7P874vSVrISNZUaioUWdpcQ6WSDInSYgktEoqiJGYmlWRJ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        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVVXk0lYsXdb977/dFpBJRqZQKtzTQRDknKUWhDEXykkJUKKSQ9MIrhQyR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        "]]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.003666666666666667], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJztjok31A0Xx6WY5ff7HdqVpAUVSSGS7UaWtveRFpQlxZu2V+8TbZRQPGNP
tggpW1SopKJuu608spQ2yZgxM2bMGGMUxTPvn/Ge43POPfd8z/ne7/cu3Bvo
6q+spKTEVcz/dr7xvJyZJ2mQ6190UGlVN6q3h82IiqHBApdvFoXbu1F4/0jr
pys0mOTKkhme6sbN8soVemU0+P4xpEIppxt9tq5keT9T+FU+jwW86EZ0S3OM
b6XB6VPPPmryu/HeztKkYg4NTJPeue9TY+NCesaUR8M0KF3ME8lWs9FQK+BS
FYMOiVkHV8/1YiMb3aeXatJh9pUqDdZ5NroOzLOOMaTDaTFUxdxk47fjN7R9
bOlgsepaUHsbGx3yHlpqb6WD25kiScVvNlpwMjva9ir807qID3o9OGPwmG1w
EB08lF+x41x6cKqYJWZG0SHQNrYj5nQPZqm0jcSk04FvVx6hUdCDYSMGGko3
6KCvVvNS9HcPnsp6usjnER1SvsaVbR3tweoXle+KGulwVKoTb7+Eg3J2gTnn
Cx12uC/RDt3Gwchoz3ainw4E83LCunMcFF+WD+qNK/omheptucXBNv2UTn11
BlSK14f3fOJgh/bBGYsXMsBNWRL8jM7FhKjdpZONGSB83UwtM+ficXR277Bj
gODhsdvt/ly0cXT+lbKNAZ0vw94SqVyMCD0R7uDHALP4a75RL7l47HZyytcg
Blzb4LKRJeNiQVPk9gMXFHnO7KnNOr1os3Hh2i+pDLjAmjeevaMXve3KMuwK
GeA+jWVcFtWLHmEplYn3GWD9qtrN8UEv7lMand38mgEZXNmSBYJezKW7tsjf
M+C5mk7F2Xk81LA0yVXvZQCnsMpJ+w8e7tqZ5K0+rPBfjfOwj+BhfvjIb2Ua
EwrK73UUV/JwvNXX4PMsJlhVJCUl8XnoE781P0OPCWUmh4t+avGRLLYqcTZj
go7Gac3rrnxc6tea8dWBCSaJSvlvovmYVWfG9tvBhAq+I3v1Yz7OuRNwr9mP
CQdMX/dqDfJxvtPD8hVBTNicYzGyfpkAo1ljLUcjmXB77OcZvo8AVyqbS/KT
FXm3Ev3epAnQdcnF1po8Joz9xd1n0CTA2N3mEa/LmTBZp0ijTqUPd2eaZdxF
JsyhMVnfrPuw01D2PrKJCbYljfVHj/dhYUlNssNXJvSw2JdtyvqwIc5mrqBP
8d+cB+3neX0YHBMvCRthws8PQSLVRULclJFv9oNOwI+GzzQlTyFmZ7Zn+84m
IO9ntLNpmhAf7JDNuaVLwJlXAfM7m4VobaoawzchIKro8d7nhAi9Gh0qaXYE
MIUhDXOdRPhf+9A9NBcCtDweeXIjRHgpNq9y2IuAIueNen1PRFif+dm4/hAB
97SD8nxHRRjyY/eK2FMEHNAJTFNf048PZxqPGkYTMPxNiEbB/Ri0c43msxQC
hKGF16Pu9KNhyuh902sEtNUUr90s6cfUqsMhGWUEHCmxb3BeIUajCIP9X2oI
sDnREX3nsBj1wlPslBoIODuWe+SvUjEObtaeNOMDAY2OdVNSBGJsufjZk9ZD
AK90+jyVmRIMOln/p0BCwMZt8pJPphJseJzXdvM3AZxd49izXYItzB113kwS
EpNecujBEtS16qoSzyKBebyxdk+qBJ+nJvzHZzEJBt2HOvsqJdhlaxb8xIgE
2yYzz6T3EnQLH5aNWpKwdUr8uv3DEgxe9St7qTMJGvpqS9w0BvDQli3HTLaT
EFthXHDSYgB5nQ2bDPeQkH4jvfrOrgGUClRVVA6TMKbWdVkrdAAvvfiR1XiC
hNIt6UVXswewYqlXfWAkCZtuFZVswwF0+/cez4EEEirVH840+z6AV8fVk3wz
SbheHjtuNFmK2fYm328XkLBbvTfEXVeKKodsygTlJNzS+khkOEkxzeHDtsk1
JPzS0XFTOajQTRauzFoSCs9P2siKk2IY9+J30TsSAi+4a68tk2KsqmUxfiHB
88l+o0ktUtwylFh9pJcErdIDTjKZFLlz/HsYUhKm8U4s/z17EM+tFs2K+EWC
n7+r9SrLQXxR+9aap0qBZQLePO09iO8/Vi/Xn0qBt6blwf7wQfQTnxd7aFKw
TEV19omCQUz/SKz116VghWWy8bL6QbzfkrXG24iCN/1+b8XCQbRaIA0ztqCg
q11H3qkuQ5rJck+ZHQXpwj2G3aYy1ElPtL+4mQKV/ebqlIcM7zr55GnupCA3
VDlp0xkZttpnHrrkQ0HCyNOo7DwZrqyXSzgBFKSaTv0587UMWVdXvtL9k4L1
AR8C8wQy3GW2YC6EUPB+6rlQV7UhXBujlud0ngLfpiNzZ5kOof7bKBereMV9
+/TFQvchXJg8ZEqkUfBE2Tyee2YI1WJHdWtzKHDh/BBJrw2humHDDK8iCm5s
2FW7qG4I6dpS2bcyhXZOX+QnGkLnkqjHfzygQGtdbsf9aXIE37NWl59SEFn0
vMlgjRx9m1NYf9dRsC9jWkmFlxzXxxlekTZTUJxjZu8cKcfafzkuEHdQ8NT3
7vfxYjnOt7jg0tGl6F+eXFvbJMer1Tk6t3kUnNqw+m2uTI5KE0wwwQQTTPB/
yD+8s884
        "]]}}, {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}, {{{}, {}}, {}, \
{{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      GeometricTransformationBox[InsetBox[
        StyleBox["\[FilledCircle]",
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}], {0., 0.}, Automatic, Offset[
        50]], {{{-2.933634982333688, 
       0.568481643970859}}, {{-1.0663650176663122`, -0.568481643970859}}, \
{{-0.9336349823336878, 0.568481643970859}}, {{
       0.9336349823336878, -0.568481643970859}}, {{1.0663650176663122`, 
       0.568481643970859}}, {{
       2.933634982333688, -0.568481643970859}}}]}, {{}, {}}}, {}, {{}, {{{}, \
{}, {}, {}}, {}}}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  CoordinatesToolOptions:>{"DisplayFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& ), "CopiedValueFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& )},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{389., Automatic},
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "MessagesHead" -> ComplexListPlot},
  PlotRange->{{-3, 3}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.8253726028792286`*^9, {3.8253726722077403`*^9, 
   3.8253726835981627`*^9}, 3.8253727943014774`*^9, 3.825372972410427*^9, 
   3.825373711551451*^9, {3.83896715464624*^9, 3.838967179786746*^9}},
 CellLabel->
  "Out[123]=",ExpressionUUID->"e39bf953-9b31-4341-8f8e-132e5226c51a"]
}, Open  ]]
},
WindowSize->{1904, 991},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{
 "WelcomeScreenSettings" -> {"FEStarting" -> True}, "TryRealOnly" -> False},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (2021\:5e742\:67082\
\:65e5)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d8ad1501-45a3-4fb6-ab47-a516cc4c16f2"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 677, 14, 108, "Input",ExpressionUUID->"bc70f9da-5b8a-493c-9dbf-7c6d8cd4633d"],
Cell[CellGroupData[{
Cell[1260, 38, 25309, 617, 1207, "Input",ExpressionUUID->"b64d2191-17bf-44d5-9569-bb0d8fa1db1c"],
Cell[26572, 657, 21066, 359, 265, "Output",ExpressionUUID->"3369bca6-f278-400c-a62b-a96e92aab0d4"],
Cell[47641, 1018, 2996, 60, 116, "Output",ExpressionUUID->"1e552e77-bff1-4ed2-b8f7-d802958df240"],
Cell[50640, 1080, 1660, 25, 32, "Output",ExpressionUUID->"24453182-35cf-4463-84b3-7aae66d2b708"],
Cell[52303, 1107, 90824, 1538, 284, "Output",ExpressionUUID->"e39bf953-9b31-4341-8f8e-132e5226c51a"]
}, Open  ]]
}
]
*)

